@@ -53,8 +53,8 @@ def main():
                                ["Resources", "adding.qrc"],
                                ["QML", "example.qml"]]:
         filenames = ["ABCD" + filename.upper(), "abcd" + filename.lower(), "test", "TEST", filename]
-        if (filename.endswith(".qrc") and JIRA.isBugStillOpen(20101)):
-            filenames.remove("ABCD" + filename.upper())
+        if filename.endswith(".qrc"):
+            filenames = ["ABCD" + filename.lower(), "abcd" + filename.lower(), filename]
         previous = filenames[-1]
         for filename in filenames:
             tempFiletype = filetype
@@ -96,20 +96,20 @@ def renameFile(projectDir, proFile, branch, oldname, newname):
         itemWithWildcard = addBranchWildcardToRoot(itemText)
         waitForObjectItem(treeview, itemWithWildcard, 10000)
         openItemContextMenu(treeview, itemWithWildcard, 5, 5, 0)
-    # hack for Squish5/Qt5.2 problems of handling menus on Mac - remove asap
-    if platform.system() == 'Darwin':
-        waitFor("macHackActivateContextMenuItem('Rename...')", 5000)
+    if oldname.lower().endswith(".qrc"):
+        menu = ":Qt Creator.Project.Menu.Folder_QMenu"
     else:
-        if oldname.lower().endswith(".qrc"):
-            menu = ":Qt Creator.Project.Menu.Folder_QMenu"
-        else:
-            menu = ":Qt Creator.Project.Menu.File_QMenu"
-        activateItem(waitForObjectItem(menu, "Rename..."))
+        menu = ":Qt Creator.Project.Menu.File_QMenu"
+    activateItem(waitForObjectItem(menu, "Rename..."))
     replaceEdit = waitForObject(":Qt Creator_Utils::NavigationTreeView::QExpandingLineEdit")
     test.compare(replaceEdit.selectedText, oldname.rsplit(".", 1)[0],
                  "Only the filename without the extension is selected?")
     replaceEditorContent(replaceEdit, newname)
     type(replaceEdit, "<Return>")
+    if oldname == "adding.qrc":
+        clickButton(waitForObject("{text='No' type='QPushButton' unnamed='1' visible='1' "
+                                  "window={type='QMessageBox' unnamed='1' visible='1' "
+                                  "        windowTitle='Rename More Files?'}}"))
     test.verify(waitFor("os.path.exists(newFilePath)", 1000),
                 "Verify that file with new name exists: %s" % newFilePath)
     test.compare(readFile(newFilePath), oldFileText,
